<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2004/10/xpath-functions" xmlns:xdt="http://www.w3.org/2004/10/xpath-datatypes">
    <xsl:output version="1.0" encoding="UTF-8" indent="no" omit-xml-declaration="no" media-type="text/html" />
    <xsl:template match="/">
        <html>
            <head>
                <title />
            </head>
            <body>
                <xsl:for-each select="WUFI2D">
                    <br />
                    <h2>
                        <center>WUFI2D Project Overview</center>
                    </h2>
                    <br /><b>Info:</b><xsl:for-each select="Info">
                        <br />
                        <br />Projectname: <xsl:apply-templates select="ProjectName" />
                        <br />Contact: <xsl:apply-templates select="Contact" />
                        <br />Phone: <xsl:apply-templates select="Phone" />
                        <br />City-Zip: <xsl:apply-templates select="City-Zip" />
                        <br />Street: <xsl:apply-templates select="Street" />
                        <br />Client: <xsl:apply-templates select="Client" />
                        <br />Number: <xsl:apply-templates select="Number" />
                        <br />Remarks: <xsl:apply-templates select="Remarks" />
                        <br />e-Mail: <xsl:apply-templates select="eMail" />
                        <br />Responsible: <xsl:apply-templates select="Responsible" />
                        <br />Fax: <xsl:apply-templates select="Fax" />
                        <!--<br />Comment: <xsl:apply-templates select="Comment" />-->
                        <br />Date of creation: <xsl:apply-templates select="Date" />
                        <br />
                        <br />
                    </xsl:for-each>
                    <br /><b>Construction:</b><br />
                    <xsl:for-each select="Construction">
                        <xsl:for-each select="Definition">
                          <br /><img src="def.png" width="50%" />
                          <br />
                        </xsl:for-each>
                        <br />
                        <xsl:for-each select="Path">
                            <br /><b>Rectangles / Orthogonal Polygons:</b><br />
                            <xsl:for-each select="OrthoPolygons">
                              <table border="1">
                                <tr>
                                  <td>&#160;Name&#160;</td>
                                  <td>&#160;XMaterialFilename&#160;</td>
                                  <td>&#160;YMaterialFilename&#160;</td>
                                  <td>&#160;Initial Theta&#160;</td>
                                  <td>&#160;Initial Phi&#160;</td>
                                  <td>&#160;Initial WaterContent&#160;</td>
                                </tr>
                                <xsl:apply-templates/>
                              </table>
                            </xsl:for-each>
                            <br />
                            <xsl:if test="string-length(normalize-space(//Numeric/ThetaInitialFile))!=0">
                              File of Initial Conditions for Temperature: 
                              <xsl:value-of select="//Numeric/ThetaInitialFile"/>
                              <br />
                            </xsl:if>
                            <xsl:if test="string-length(normalize-space(//Numeric/PhiInitialFile))!=0">
                              File of Initial Conditions for Relative Humidity:
                              <xsl:value-of select="//Numeric/PhiInitialFile"/>
                              <br />
                            </xsl:if>


                          <br /><b>Outersurfaces:</b><br />
                            <xsl:for-each select="OuterSurfaces">
                              <xsl:value-of select="Count"/>
                              <br /><img src="surf.png" width="50%"></img>
                              <br />
                              <br /><b>Surface Coefficients:</b>
                              <br />
                              <table border="1">
                                <tr>
                                  <td>&#160;Name&#160;</td>
                                  <td>&#160;Heat Transfer Coefficient&#160;</td>
                                  <td>&#160;SD-Value&#160;</td>
                                  <td>&#160;Rain Absorption&#160;</td>
                                  <td>&#160;Radiation Absorption&#160;</td>
                                  <td>&#160;Radiation Emissivity&#160;</td>
                                </tr>
                                <xsl:apply-templates select="Attributes"/>
                              </table>
                              <br /><b>Climate:</b><br />
                              <br />
                              <table border="1">
                                <tr>
                                  <td>&#160;ClimateFile&#160;</td>
                                  <td>&#160;Orientation&#160;</td>
                                  <td>&#160;Inclination&#160;</td>
                                </tr>
                                <xsl:apply-templates select="Attributes/Attribute/BoundaryConditions/Climate"/>
                              </table>
                            </xsl:for-each>
                            <br />
                            <b>Sources:</b><br />
                            <xsl:for-each select="Sources">
                              <xsl:value-of select="Count"/>
                              <br />
                              <xsl:if test="Count>0">
                                <br />
                                <table border="1">
                                  <tr>
                                    <td>&#160;Name&#160;</td>
                                    <td>&#160;Type&#160;</td>
                                    <td>&#160;Fraction&#160;</td>
                                    <td>&#160;FileName&#160;</td>
                                    <td>&#160;Associated Boundary&#160;</td>
                                  </tr>
                                  <xsl:apply-templates select="Source"/>
                                </table>
                                <br />
                                <img src="source.png" width="50%"></img>
                                <br />
                              </xsl:if>
                            </xsl:for-each>
                            <br /><b>Grid:</b><br />
                            <xsl:for-each select="Grid">
                                <img src="grid.png" width="50%" />
                                <br />
                                <br />X-Direction:<br />
                                <xsl:for-each select="X-Direction">
                                    <br />Number of layers: <xsl:apply-templates select="NLayer" />
                                    <br />Mode of generation: <xsl:apply-templates select="Mode" />
                                    <br />Number of elements: <xsl:apply-templates select="Splitting" />
                                    <br />Dimension [mm]: <xsl:apply-templates select="Dimension" />
                                    <br />Expansion factor: <xsl:apply-templates select="Geometry" />
                                    <br />
                                </xsl:for-each>
                                <br />Y-Direction:<br />
                                <xsl:for-each select="Y-Direction">
                                    <br />Number of layers: <xsl:for-each select="NLayer">
                                        <xsl:apply-templates />
                                    </xsl:for-each>
                                    <br />Mode of generation: <xsl:for-each select="Mode">
                                        <xsl:apply-templates />
                                    </xsl:for-each>
                                    <br />Number of elements: <xsl:for-each select="Splitting">
                                        <xsl:apply-templates />
                                    </xsl:for-each>
                                    <br />Dimension [mm]: <xsl:for-each select="Dimension">
                                        <xsl:apply-templates />
                                    </xsl:for-each>
                                    <br />Expansion factor: <xsl:for-each select="Geometry">
                                        <xsl:apply-templates />
                                    </xsl:for-each>
                                    <br />
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:for-each>
                    <br />
                    <xsl:for-each select="Numeric">
                        <br /><b>Computational Parameters:</b><br />
                        <br />Timestep [s]: <xsl:apply-templates select="Timestep" />
                        <br />Number of timesteps: <xsl:apply-templates select="TimestepCount" />
                        <br />Convergence criterion: <xsl:apply-templates select="ConvergenceCrit" />
                        <br />Max. number of iterations: <xsl:apply-templates select="MaxIt" />
                        <br />Include Heat of Evaporation: <xsl:apply-templates select="HasHeatOfEvaporation" />
                        <br />Include Heat of Fusion: <xsl:apply-templates select="HasHeatOfFusion" />
                        <br />Take capillary conduction into account: <xsl:apply-templates select="HasCapillaryConduction" />
                        <br />
                      </xsl:for-each>
                    <br />
                </xsl:for-each>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template match="OrthoPolygon">
      <xsl:variable name="xmaterial">
        <xsl:value-of select="XMaterialFilename" />
      </xsl:variable>
      <xsl:variable name="ymaterial">
        <xsl:value-of select="YMaterialFilename" />
      </xsl:variable>
      <tr>
        <td>
          <xsl:apply-templates select="ID" />
        </td>
        <td>
          <a href="{$xmaterial}">
            <xsl:value-of select="$xmaterial"/>
          </a>
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="$ymaterial=$xmaterial">
              <xsl:value-of select="'ditto'"/>
            </xsl:when>
            <xsl:otherwise>
              <a href="{$ymaterial}">
                <xsl:value-of select="$ymaterial"/>
              </a>
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="string-length(normalize-space(//Numeric/ThetaInitialFile))=0">
              <xsl:apply-templates select="InitialTheta" />
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="'n.a.'"/>    
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <xsl:choose>   
            <xsl:when test="string-length(normalize-space(//Numeric/PhiInitialFile))=0">
              <xsl:apply-templates select="InitialPhi" />
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="'n.a.'"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <xsl:choose>   
            <xsl:when test="string-length(normalize-space(//Numeric/PhiInitialFile))=0">
            <xsl:apply-templates select="InitialW" />
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="'n.a.'"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
    </xsl:template>
  
    <xsl:template match="Attribute">
      <tr>
        <td>
          <xsl:apply-templates select="Name" />
        </td>
        <td>
          <xsl:apply-templates select="HeatTransferCoefficient" />
        </td>
        <td>
          <xsl:apply-templates select="SD" />
        </td>
        <td>
          <xsl:apply-templates select="RainAbsorption" />
        </td>
        <td>
          <xsl:apply-templates select="RadiationAbsorption" />
        </td>
        <td>
          <xsl:apply-templates select="RadiationEmissivity" />
        </td>
      </tr>
    </xsl:template>
  
    <xsl:template match="Climate">
      <xsl:variable name="device" select="substring-before(Filename,'\')"/>
      <xsl:variable name="len">
        <xsl:value-of select="string-length(Filename)"/>
      </xsl:variable>
      <tr>
        <td> 
          <xsl:choose>
            <xsl:when test="ClimateFileSelectType='0'">
              <xsl:value-of select="ClimateFileNumber"/>
            </xsl:when>
            <xsl:when test="ClimateFileSelectType='1'">
              <xsl:choose>
                <xsl:when test ="$len>90">
                  <xsl:value-of select="concat($device,'\..',substring(Filename,90))"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="Filename"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:when>
          </xsl:choose>
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="Azimut='0'">
              <xsl:value-of select="'South'"/>
            </xsl:when>
            <xsl:when test="Azimut='90'">
              <xsl:value-of select="'West'"/>
            </xsl:when>
            <xsl:when test="Azimut='+90'">
              <xsl:value-of select="'West'"/>
            </xsl:when>
            <xsl:when test="Azimut='-90'">
              <xsl:value-of select="'East'"/>
            </xsl:when>
            <xsl:when test="Azimut='270'">
              <xsl:value-of select="'East'"/>
            </xsl:when>
            <xsl:when test="Azimut='180'">
              <xsl:value-of select="'North'"/>
            </xsl:when>
            <xsl:when test="Azimut='+180'">
              <xsl:value-of select="'North'"/>
            </xsl:when>
            <xsl:when test="Azimut='-180'">
              <xsl:value-of select="'North'"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="Azimut"/>
            </xsl:otherwise>  
          </xsl:choose>
        </td>
        <td>
          <xsl:apply-templates select="Inclination" />
        </td>
      </tr>
    </xsl:template>

    <xsl:template match="Source">
      
      <xsl:variable name="AttID">
        <xsl:value-of select="AttributeID" />
      </xsl:variable> 
      
      <tr>
        <td>
          <xsl:apply-templates select="Name" />
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="Type='0'">
              <xsl:value-of select="'Heat Source'"/>
            </xsl:when>
            <xsl:when test="Type='1'">
              <xsl:value-of select="'Moisture Source'"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="'Air Exchange Source'"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="IsConstant='TRUE'">
              <xsl:value-of select="Value"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="'-'"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="IsConstant='FALSE'">
              <xsl:value-of select="FileName"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="'-'"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="IsConstant='TRUE'">
              <xsl:value-of select="//Attribute[ID=$AttID]/Name"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="'-'"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
    </xsl:template>
  
</xsl:stylesheet>
